"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.releaseLockOnProcessExit = exports.releaseLock = exports.checkIfEnvIsLock = void 0;
const tslib_1 = require("tslib");
const remote_state_1 = require("@microlambda/remote-state");
const config_1 = require("@microlambda/config");
const ora_1 = tslib_1.__importDefault(require("ora"));
const utils_1 = require("@microlambda/utils");
const init_1 = require("./init");
const process = tslib_1.__importStar(require("process"));
const checkIfEnvIsLock = async (cmd, env, project, config, logger) => {
    let lock;
    if (!cmd.skipLock) {
        lock = new remote_state_1.LockManager(config.state.table, config.defaultRegion, env.name, cmd.s?.split(',') || [...project.services.keys()]);
        if (await lock.isLocked()) {
            logger?.info('🔒 Environment is locked. Waiting for the lock to be released');
            await lock.waitLockToBeReleased();
        }
        await lock.lock();
    }
    return async (msg) => {
        if (lock) {
            try {
                if (logger)
                    process.stdout.write('\n');
                const lockRelease = (0, ora_1.default)(msg || '🔒 Releasing lock...');
                await lock?.releaseLock();
                lockRelease.succeed('🔒 Lock released !');
            }
            catch (e) {
                logger?.error('Error releasing lock, you probably would have to do it yourself !', e);
                throw e;
            }
        }
    };
};
exports.checkIfEnvIsLock = checkIfEnvIsLock;
const releaseLock = async (options, logger) => {
    const projectRoot = (0, utils_1.resolveProjectRoot)();
    const { config, project } = await (0, init_1.init)(projectRoot);
    const stateConfig = (0, config_1.getStateConfig)(config, options.account);
    const lock = new remote_state_1.LockManager(stateConfig.state.table, stateConfig.defaultRegion, options.env, options.services?.split(',') || [...project.services.keys()]);
    const lockRelease = logger ? (0, ora_1.default)('🔒 Releasing lock...') : undefined;
    if (logger)
        process.stdout.write('\n');
    try {
        if (await lock.isLocked()) {
            await lock.releaseLock();
            lockRelease?.succeed('🔒 Lock released !');
        }
        else {
            lockRelease?.succeed('🔒 Lock already released');
        }
        process.exit(0);
    }
    catch (e) {
        logger?.error('Error releasing lock, you probably would have to do it yourself !', e);
        process.exit(1);
    }
};
exports.releaseLock = releaseLock;
const releaseLockOnProcessExit = (release, logger) => {
    process.on('SIGINT', async () => {
        try {
            await release('🔒 SIGINT received, releasing lock...');
            process.exit(0);
        }
        catch (e) {
            logger?.error('Error releasing lock, you probably would have to do it yourself !');
            process.exit(2);
        }
    });
};
exports.releaseLockOnProcessExit = releaseLockOnProcessExit;
//# sourceMappingURL=check-env-lock.js.map