"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Project = void 0;
const runner_core_1 = require("@microlambda/runner-core");
const workspace_1 = require("./workspace");
const resolve_ports_1 = require("../resolve-ports");
const config_1 = require("@microlambda/config");
class Project extends runner_core_1.Project {
    logger;
    _services = new Map();
    _packages = new Map();
    constructor(prj, logger) {
        super(prj.pkg, prj.root, prj._config, prj.project);
        this.logger = logger;
    }
    static scope = 'core/project';
    get log() {
        return this.logger;
    }
    static async loadProject(root, logger) {
        const log = logger?.scope(Project.scope);
        log?.info('Loading project');
        const centipodProject = await super.loadProject(root, logger);
        log?.info('Found', centipodProject.workspaces.size, 'workspaces');
        const prj = new Project(centipodProject, log);
        for (const [name, workspace] of centipodProject.workspaces.entries()) {
            const milaWorkspace = new workspace_1.Workspace(workspace);
            if (milaWorkspace.isService) {
                prj._services.set(name, milaWorkspace);
            }
            else {
                prj._packages.set(name, milaWorkspace);
            }
            prj._workspaces.set(name, milaWorkspace);
        }
        log?.info('Found', prj.packages.size, 'packages');
        log?.info('Found', prj.services.size, 'services');
        log?.info('Resolving ports');
        const ports = await (0, resolve_ports_1.resolvePorts)([...prj.workspaces.values()], new config_1.ConfigReader(root));
        prj.services.forEach((s) => {
            log?.info('Service', s.name, 'is assigned port', ports[s.name]?.http);
            s.assignPorts(ports[s.name]);
        });
        return prj;
    }
    getWorkspace(name) {
        return this.project.workspaces.get(name);
    }
    get services() {
        return this._services;
    }
    get packages() {
        return this._packages;
    }
}
exports.Project = Project;
//# sourceMappingURL=project.js.map