"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Workspace = void 0;
const runner_core_1 = require("@microlambda/runner-core");
const fs_1 = require("fs");
const path_1 = require("path");
const utils_1 = require("@microlambda/utils");
const types_1 = require("@microlambda/types");
const file_1 = require("../log-handlers/file");
class Workspace extends runner_core_1.Workspace {
    constructor(wks, ports) {
        super(wks.pkg, wks.root, wks._config, wks.project);
        this._ports = ports;
        this._attachDefaultHandlers();
    }
    _ports;
    _isService = null;
    _isSlsService = null;
    _transpiled = types_1.TranspilingStatus.NOT_TRANSPILED;
    _typechecked = types_1.TypeCheckStatus.NOT_CHECKED;
    _started = null;
    _metrics = {};
    get transpiled() {
        return this._transpiled;
    }
    get typechecked() {
        return this._typechecked;
    }
    get started() {
        return this._started;
    }
    get ports() {
        return this._ports;
    }
    get metrics() {
        return this._metrics;
    }
    assignPorts(ports) {
        this._ports = ports;
    }
    updateStatus() {
        return {
            transpiled: (to) => (this._transpiled = to),
            typechecked: (to) => (this._typechecked = to),
            started: (to) => (this._started = this._isService ? to : null),
        };
    }
    updateMetric() {
        return {
            transpile: (metric) => (this._metrics.transpile = metric),
            typecheck: (metric) => (this._metrics.typecheck = metric),
            start: (metric) => (this._metrics.start = metric),
        };
    }
    get isService() {
        if (this._isService == null) {
            this._isService = this._checkIfService();
        }
        return this._isService;
    }
    _checkIfService() {
        return this.config.hasOwnProperty('start');
    }
    get isSlsService() {
        if (this._isSlsService == null) {
            this._isSlsService =
                (0, fs_1.existsSync)((0, path_1.join)(this.root, 'serverless.yml')) || (0, fs_1.existsSync)((0, path_1.join)(this.root, 'serverless.yaml'));
        }
        return this._isSlsService;
    }
    async transpile() {
        await (0, utils_1.transpileFiles)(this.root);
    }
    _attachDefaultHandlers() {
        const inMemory = new runner_core_1.InMemoryLogHandler(this);
        const files = new file_1.LogsFileHandler(this);
        this.addLogsHandler(inMemory);
        this.addLogsHandler(files);
    }
}
exports.Workspace = Workspace;
//# sourceMappingURL=workspace.js.map