"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tailLogs = exports.createLogFile = exports.recreateLogDirectory = exports.getLogsPath = exports.getLogsDirectory = void 0;
const fs_1 = require("fs");
const rimraf_1 = require("rimraf");
const path_1 = require("path");
const child_process_1 = require("child_process");
const getLogsDirectory = (projectRoot) => (0, path_1.join)(projectRoot, '.mila', 'logs');
exports.getLogsDirectory = getLogsDirectory;
const getLogsPath = (projectRoot, service, type, region) => {
    const segments = service.split('/');
    const name = segments[segments.length - 1];
    const fieName = region ? `${name}.${type}.${region}.log` : `${name}.${type}.log`;
    return (0, path_1.join)((0, exports.getLogsDirectory)(projectRoot), fieName);
};
exports.getLogsPath = getLogsPath;
const recreateLogDirectory = (projectRoot, logger) => {
    const logsDirectory = (0, exports.getLogsDirectory)(projectRoot);
    if (!(0, fs_1.existsSync)(logsDirectory)) {
        (0, fs_1.mkdirSync)(logsDirectory, { recursive: true });
        return;
    }
    if (!(0, fs_1.lstatSync)(logsDirectory).isDirectory()) {
        logger.scope('logs').error(`${logsDirectory} is not a directory`);
        process.exit(1);
    }
    (0, rimraf_1.rimrafSync)(logsDirectory);
    (0, fs_1.mkdirSync)(logsDirectory);
};
exports.recreateLogDirectory = recreateLogDirectory;
const createLogFile = (projectRoot, service, type, region) => {
    const logsPath = (0, exports.getLogsPath)(projectRoot, service, type, region);
    if (!(0, fs_1.existsSync)((0, path_1.dirname)(logsPath))) {
        (0, fs_1.mkdirSync)((0, path_1.dirname)(logsPath), { recursive: true });
    }
    if (!(0, fs_1.existsSync)(logsPath)) {
        (0, fs_1.closeSync)((0, fs_1.openSync)(logsPath, 'w'));
    }
};
exports.createLogFile = createLogFile;
const tailLogs = (serviceName, projectRoot, logger) => {
    const logsDirectory = (0, exports.getLogsDirectory)(projectRoot);
    (0, fs_1.stat)(`${logsDirectory}/${serviceName}.log`, (exists) => {
        if (exists === null) {
            (0, child_process_1.spawnSync)('tail', ['-n', '+1', `${logsDirectory}/${serviceName}.log`], {
                stdio: 'inherit',
            });
        }
        else {
            logger
                .scope('logs')
                .error(`There is not logs for the ${serviceName} service or the service specified does not exist.\n\tPlease run 'mila start' command first!`);
        }
    });
};
exports.tailLogs = tailLogs;
//# sourceMappingURL=logs.js.map