"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolvePorts = void 0;
const resolvePorts = async (services, configReader, logger, defaultPorts = { lambda: 2001, http: 3001, websocket: 6001 }) => {
    const result = {};
    await Promise.all(services
        .filter((s) => s.hasCommand('start'))
        .map(async (service) => {
        const config = await configReader.loadPackageConfig(service.name, service.root);
        logger?.scope('port').debug('Resolving port from config', config);
        const fromConfig = {};
        const ports = config.ports;
        if (ports) {
            if (typeof ports === 'number') {
                fromConfig.http = ports;
            }
            else {
                if (ports?.http) {
                    fromConfig.http = ports.http;
                }
                if (ports?.lambda) {
                    fromConfig.lambda = ports.lambda;
                }
                if (ports?.websocket) {
                    fromConfig.websocket = ports.websocket;
                }
            }
        }
        result[service.name] = {
            ...defaultPorts,
            ...fromConfig,
        };
        defaultPorts.http++;
        defaultPorts.lambda++;
        defaultPorts.websocket++;
    }));
    logger?.scope('port').debug('Ports resolved', result);
    return result;
};
exports.resolvePorts = resolvePorts;
//# sourceMappingURL=resolve-ports.js.map