import { Observable } from 'rxjs';
import { EventsLog } from '@microlambda/logger';
import { Workspace } from './graph/workspace';
import { Project } from './graph/project';
import { RunCommandEvent } from '@microlambda/runner-core';
export type SchedulerEvent = RunCommandEvent & {
    cmd: 'start' | 'transpile' | 'build';
};
export declare class Scheduler {
    readonly project: Project;
    readonly defaultRegion: string;
    private readonly _logger;
    private readonly _concurrency;
    private readonly _runner;
    private _process;
    constructor(project: Project, defaultRegion: string, logger: EventsLog, concurrency?: number);
    startOne(service: Workspace): void;
    startAll(): void;
    stopOne(service: Workspace): void;
    gracefulShutdown(): void;
    stopAll(): void;
    restartOne(service: Workspace): void;
    restartAll(): void;
    get execution$(): Observable<SchedulerEvent>;
    exec(initialScope: Workspace[], debounce: {
        transpile: number;
        build: number;
        start: number;
    }): Observable<SchedulerEvent>;
    private get _startArgs();
    private get _ports();
    private _resolveEnvs;
}
