"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.yarnInstall = void 0;
const tslib_1 = require("tslib");
const ora_1 = tslib_1.__importDefault(require("ora"));
const execa_1 = require("execa");
const yarnInstall = async (project, logger, eventsLog) => {
    const installing = logger ? (0, ora_1.default)('Installing dependencies 📦').start() : undefined;
    try {
        await (0, execa_1.command)('yarn install', {
            cwd: project.root,
            stdio: process.env.MILA_DEBUG?.split(',').includes('yarn') ? 'inherit' : 'pipe',
        });
    }
    catch (e) {
        const message = 'Error installing microservices dependencies. Run in verbose mode (export MILA_DEBUG=yarn) for more infos.';
        eventsLog?.scope('bootstrap').error(e);
        eventsLog?.scope('bootstrap').error(message);
        logger?.error('\n' + message);
        process.exit(1);
    }
    if (installing) {
        installing.text = 'Dependencies installed 📦';
        installing.succeed();
    }
};
exports.yarnInstall = yarnInstall;
//# sourceMappingURL=yarn-install.js.map